@@ -14,7 +14,7 @@ from .strength_solver import RampCorpSolver
 from .strength_solver import BeltZoneSolver
 from .strength_solver import APFSDStrengthSolver
 
-from .mcdrag_solver import McDragSolver
+# from .mcdrag_solver import McDragSolver
 
 from .eb_solver import PointMassTrajectoryHSolver
 from .eb_solver import PointMassTrajectorySolver
