@@ -168,6 +168,10 @@ class PointMassTrajectoryHSolver:
         self.preprocess_data['v0'] = data['initial_cond']['V']
         self.preprocess_data['cx_list'] = global_state['kontur_solver']['cx_list']
         self.preprocess_data['mach_list'] = global_state['kontur_solver']['mach_list']
+        print(self.preprocess_data['A'])
+        print(self.preprocess_data['B'])
+        print(self.preprocess_data['L'])
+        print(self.preprocess_data['h'])
 
     def _get_fortran_shell(self):
 
