@@ -335,7 +335,7 @@ class OFSMCCSolver:
         return result_params
 
     # Расчёт гироскоп. коэфф. на вылете
-    def gyro_stab(self, q, A, B, mu, xc, p_data):
+    def gyro_stab(self, q, A, B, mu, xc, R6_cur, p_data):
         km = np.array([0.97, 0.98, 1.0, 1.03, 1.06, 1.07, 1.06, 1.05, 1.04, 1.03, 1.02, 1.01, 1.0, 0.99, 0.98, 0.97,
                        0.96, 0.95, 0.94, 0.93, 0.92, 0.91, 0.9, 0.89, 0.88])
 
@@ -351,7 +351,7 @@ class OFSMCCSolver:
         d = p_data['gun']['d']
         fi = 0.57
         sizes = p_data['shell_size']
-        L_corp = sizes['R1'] + sizes['R2'] + sizes['R3'] + sizes['R4'] + sizes['R6'] + sizes['R7'] + sizes['R8']
+        L_corp = sizes['R1'] + sizes['R2'] + sizes['R3'] + sizes['R4'] + R6_cur + sizes['R7'] + sizes['R8']
         L = L_corp + sizes['R27']
 
         Hg = L - p_data['corpus_coord'][0, 11]
@@ -360,10 +360,6 @@ class OFSMCCSolver:
         h0 = p_data['corpus_coord'][0, 11] - xc
         h1 = fi * Hg - 0.16 * d
 
-        sizes = p_data['shell_size']
-        L_corp = sizes['R1'] + sizes['R2'] + sizes['R3'] + sizes['R4'] + sizes['R6'] + sizes['R7'] + sizes['R8']
-        L = L_corp + sizes['R27']
-
         h = h0 + h1
 
         if L <= 4.5 * d:
@@ -416,7 +412,9 @@ class OFSMCCSolver:
         hb = sizes['R17'] - (d / 2)   # Высота пояска
         xct = state['geometry_solver']['L_all'] - xc # Координата центра тяжести (ОТ НОСИКА !!!)
 
+        R6_cur = state['geometry_solver']['R6']
         R_d = d / 2
+
         # Колпачок взрывателя
 
         fuse_nose = {'type': 1, 'x1': 0., 'x2': sizes['R29'], 'r1': sizes['R28'], 'r2': sizes['R28'], 'R': 0., 'n': 0.}
@@ -431,7 +429,7 @@ class OFSMCCSolver:
 
 
         # Цилиндр снаряда (до зпч)
-        h_cyl = h_oj + sizes['R7'] + sizes['R6'] + sizes['R4'] + sizes['R3'] + sizes['R2']
+        h_cyl = h_oj + sizes['R7'] + R6_cur + sizes['R4'] + sizes['R3'] + sizes['R2']
         cyl_shell = {'type': 1, 'x1': h_oj, 'x2': h_cyl, 'r1': R_d, 'r2': R_d, 'R': 0., 'n': 0.}
 
 
@@ -471,6 +469,7 @@ class OFSMCCSolver:
         # Получаем новое значение R6, округляем по максимуму, до 4 знакам в мм. Дальше просто нет физического смысла
         R6 = round(self.correct_mass(q, p_data), 4)
 
+
         # Пока убираем возможность задавать точность коррекции, потому что легко свалиться в рекурсию
         # Массу снаряда подгоняем по 2 знаку после запятой
         if abs(q - p_data['q_sh']) > 1E-2 and correct_mass_status:
@@ -502,7 +501,7 @@ class OFSMCCSolver:
             c_q = (q / p_data['gun']['d'] ** 3) * 1e-3
 
             # Определяем коэфф. гироскопич. устойчивости и расст. между ЦС и ЦМ
-            sigma_0, h = self.gyro_stab(q, A, B, mu, xc, p_data)
+            sigma_0, h = self.gyro_stab(q, A, B, mu, xc, R6, p_data)
 
             # Коэффициент наполнения
             alpha = explosive_params['q'] / q
