@@ -972,7 +972,7 @@ class RampCorpSolver:
 
 
         # Прогиб наружней поверхности корпуса снаряда
-        k = -1 * (q_oc / q_oc)  # меняем знак для последнего множителя формул
+        k = q_oc/np.abs(q_oc) * -1  # меняем знак для последнего множителя формул
         # Если мы в упругой зоне, считаем упругий прогиб
         if P_rad < Pkr1:
             Wh_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (P_rad - (q_oc / (ro_5 * np.sqrt(3))))
@@ -980,14 +980,14 @@ class RampCorpSolver:
         # Если мы в сложно-напряженном состоянии
         elif Pkr1 <= P_rad < Pkr2:
             Wh_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (1 / np.sqrt(1 + u ** 2 * ro_5 ** 4)) * (
-                        u + k * (1 / (ro_5 * np.sqrt(3))))
+                        u + (k * (1 / (ro_5 * np.sqrt(3)))))
             status = 'материал в упруго-пластической зоне'
         # Если мы в пластической зоне
         elif Pkr2 <= P_rad < Pkr3:
             Wh_sh = (np.sqrt(3) / 2) * eps_sh * r5 * (1 / (np.sqrt(1 + u ** 2 * ro_5 ** 4)) +
                                                        ((u * ro_5 ** 2) / (1 + ro_5 ** 2 * u ** 2)) * (
                                                                    (P_rad - Pkr2) / (1 - lambd))) * (
-                                 u + k * (1 / (ro_5 * np.sqrt(3))))
+                                 u + (k * (1 / (ro_5 * np.sqrt(3)))))
             status = 'материал в пластической зоне'
 
         # Влияние близости дна
@@ -996,6 +996,7 @@ class RampCorpSolver:
         Y_5 = 0.5 * (np.sqrt(3) / np.sqrt(2)) * (l / np.sqrt(a_5 * h_5))
         k_s = 1 - (np.cos(Y_5) + np.sin(Y_5)) * np.exp(-Y_5)
 
+
         # Прогиб стенки корпуса снаряда
         WH = k_s * Wh_sh
 
